@@ -1,24 +1,11 @@
-"Image" <-
-function(x, y=NULL, pixs=1, zmax=NULL, ztransf=function(x){x},
-                  colramp=IDPcolorRamp, factors=c(FALSE,FALSE))
+`Image` <-
+function(x, y = NULL, pixs = 1, zmax = NULL,
+                  ztransf = function(x){x},
+                  colramp = IDPcolorRamp, factors = c(FALSE,FALSE))
   ## Authors: Andreas Ruckstuhl, Rene Locher
-  ## Version: 2005-10-17
+  ## Version: 2007-05-28
 {
-  if (is.matrix(x) | is.data.frame(x)) {
-    if (ncol(x)>1) {
-      if (is.null(y)) y <- x[,2] else
-          stop("'x' must have only 1 column when y is supplied separately\n")
-    }
-    x <- x[,1]
-  }
-  
-  if (is.null(y)) {
-    y <- x
-    x <- 1:length(x)
-  }
-  if (length(y)!=length(x)) stop("Vector 'y' must have the same length as 'x'\n")
-  
-  xy <- NaRV.omit(data.frame(x,y))
+  xy <- NaRV.omit(getXY(x,y))
   factors <- factors | sapply(xy,is.factor)
   xy <- sapply(xy,as.numeric)
 
@@ -32,17 +19,17 @@ function(x, y=NULL, pixs=1, zmax=NULL, ztransf=function(x){x},
     bx <- seq(usr[1],usr[2], length=round(par("pin")/pixs)[1]+1)
   }
 
-   if (factors[2]) {
-     by <- seq(min(xy[,2]-0.25), max(xy[,2]+0.25),
-               length=2*diff(range(xy[,2]))+2)
-   } else {
-     by <- seq(usr[3],usr[4], length=round(par("pin")/pixs)[2]+1)
-   }
+  if (factors[2]) {
+    by <- seq(min(xy[,2]-0.25), max(xy[,2]+0.25),
+              length=2*diff(range(xy[,2]))+2)
+  } else {
+    by <- seq(usr[3],usr[4], length=round(par("pin")/pixs)[2]+1)
+  }
   
   zz <- ztransf(table(cut(xy[,1],b=bx), cut(xy[,2], b=by)))
-  zzmax <- max(zz)
+  zzmax <- ceiling(max(zz))
 
-  if(is.null(zmax)) zmax <- zzmax
+  if(is.null(zmax)) zmax <- zzmax else zmax <- ceiling(zmax)
   if(zmax<1||is.null(zmax)) {
     stop("zmax must be >= 1 and
           plot(x,y,...) must have been called before calling this function!\n")
@@ -51,7 +38,7 @@ function(x, y=NULL, pixs=1, zmax=NULL, ztransf=function(x){x},
   if(zzmax>zmax)
     stop("zmax too small! Densiest aereas are out of range!",call. = FALSE)
 
-  zmax <- ceiling(max(zmax,2)) ## zmax must not be smaller than 2!
+  zmax <- max(zmax,2) ## zmax must not be smaller than 2!
 
   ## bg color for 0
   lbx <- length(bx)
